@@ -17,7 +17,7 @@ ml_val_t _ml_Sock_getsockname (ml_state_t *msp, ml_val_t arg)
 {
     int		sock = INT_MLtoC(arg);
     char	addrBuf[MAX_SOCK_ADDR_SZB];
-    int		addrLen = MAX_SOCK_ADDR_SZB;
+    socklen_t	addrLen = MAX_SOCK_ADDR_SZB;
     int		sts;
 
     sts = getsockname (sock, (struct sockaddr *)addrBuf, &addrLen);
